<template>
  <div class="mobile-container">
    <!--  头部  -->
    <van-sticky>
      <van-nav-bar
        title="人员详情"
        left-arrow
        @click-left="_ => $router.go(-1)"
      />
    </van-sticky>

    <van-form label-width="50px">
      <van-field
        name="账号名"
        label="账号名"
        input-align="right"
        :disabled="false"
        v-model="formData.account "
        placeholder="-"
        readonly
      />
      <van-field
        name="人员姓名"
        label="人员姓名"
        input-align="right"
        :disabled="false"
        v-model="formData.fullname "
        placeholder="-"
        readonly
      />
      <van-field
        name="性别"
        label="性别 "
        input-align="right"
        :disabled="false"
        v-model="formData.sex "
        placeholder="-"
        readonly
      />
      <van-field
        name="地址"
        label="地址"
        input-align="right"
        :disabled="false"
        v-model="formData.address "
        placeholder="-"
        readonly
      />
      <van-field
        name="维度部门"
        label="维度部门"
        input-align="right"
        rows="1"
        autosize
        type="textarea"
        :disabled="false"
        readonly
      >
        <template #input>
          {{ formData.orgStr || '-' }}
        </template>
      </van-field>
      <van-field
        name="联系电话"
        label="联系电话"
        input-align="right"
        :required="true"
        v-model="formData.mobile"
        placeholder="-"
      />
      <van-field
        name="邮箱"
        label="邮箱"
        input-align="right"
        :required="true"
        v-model="formData.email"
        placeholder="-"
      />
      <van-field
        name="账号角色"
        label="账号角色"
        input-align="right"
        rows="1"
        autosize
        type="textarea"
        clickable
        @click="showPopup('rolePopup')"
        :required="true"
        v-model="formData.roleName"
        placeholder="-"
      >
        <template #input>
          {{ formData.roleName || '-' }}
        </template>
      </van-field>

      <div class="footer">
        <van-button
          :disabled="loading"
          style="width: 80%;"
          round
          type="info"
          @click="onSubmit"
        >
          修改信息
        </van-button>
      </div>
    </van-form>

    <RolePopup
      :is-show-popup.sync="rolePopup"
      :role-name="formData.roleName"
      :routerQuery="routerQuery"
      @confirm="confirm"
    />
  </div>
</template>
<script>
import {userDetails, updateUser, addUserRole} from '@/api/Mobile/personnelManagement'
import RolePopup from './components/RolePopup/index.vue'

export default {
  name: 'AccountDetails',
  components: {RolePopup},
  data() {
    return {
      formData: {
        roleName: ''
      },
      loading: true,
      rolePopup: false // 角色选择弹出层
    }
  },
  computed: {
    routerQuery() {
      return this.$route.query
    }
  },
  created() {
    this.getDetails()
  },
  methods: {
    //获取详情
    async getDetails() {
      const {account} = this.routerQuery
      if (!account) return
      const {user, org, role: {roleName}} = await userDetails(account)
      // orgStr 维度部门，前端自行拼接位字符串
      this.formData = {
        ...user,
        orgStr: org?.reduce((concatStr, item) => {
          const {demName, orgName} = item
          return `${concatStr ? concatStr + '，' : ''}${demName}-${orgName}`
        }, '') || '',
        roleList: [],
        roleName: roleName ? roleName.split('|').map(i => i + '角色').join('，') : ''
      }
      this.loading = false
    },

    // 选择角色后
    confirm(roleList) {
      this.formData = {
        ...this.formData,
        roleName: roleList.map(i => i.name).join('，'),
        roleList
      }
    },

    //完成
    async onSubmit() {
      this.loading = true
      const {orgStr, roleList, roleName, ...formData} = this.formData
      let promiseArr = [updateUser(formData)]
      if (Array.isArray(roleList) && roleList.length) {
        promiseArr.push(addUserRole({
          roleIds: roleList.map(i => i.id).join(','),
          userId: this.routerQuery.id
        }))
      }
      const resArr = await Promise.all(promiseArr)
      if (resArr.every(i => i.state)) {
        this.$toast.success('人员信息修改成功')
      }
      this.loading = false
    },


    //  展示弹层
    showPopup(popupName) {
      this[popupName] = true
    }
  }
}
</script>
<style lang="scss" scoped>
.mobile-container {
  width: 100%;
  background-color: #f9f9f9 !important;
  box-sizing: border-box;

  .containter-sticky {
    position: fixed;
    top: 0;
    width: 100%;
    z-index: 200;
  }
}

.footer {
  width: 100%;
  position: fixed;
  bottom: 0;
  display: flex;
  justify-content: space-evenly;
  background: #fff;
  padding: 1rem;
  box-sizing: border-box;
}

.placeholder {
  color: #c7c5c5;
}

::v-deep .van-field__body {
  display: inline-block;

  div {
    display: flex;
    text-align: left;
  }
}

</style>
